@@ -497,23 +497,10 @@ public abstract class AbstractJdbcCatalog extends AbstractCatalog {
             Predicate<String> filterFunc,
             Object... params) {
 
-        List<String> columnValues = Lists.newArrayList();
-
         try (Connection conn = DriverManager.getConnection(connUrl, username, pwd);
                 PreparedStatement ps = conn.prepareStatement(sql)) {
-            if (Objects.nonNull(params) && params.length > 0) {
-                for (int i = 0; i < params.length; i++) {
-                    ps.setObject(i + 1, params[i]);
-                }
-            }
-            ResultSet rs = ps.executeQuery();
-            while (rs.next()) {
-                String columnValue = rs.getString(columnIndex);
-                if (Objects.isNull(filterFunc) || filterFunc.test(columnValue)) {
-                    columnValues.add(columnValue);
-                }
-            }
-            return columnValues;
+            return extractColumnValuesByStatement(ps, columnIndex, filterFunc, params);
+
         } catch (Exception e) {
             throw new CatalogException(
                     String.format(
@@ -522,6 +509,26 @@ public abstract class AbstractJdbcCatalog extends AbstractCatalog {
         }
     }
 
+    protected static List<String> extractColumnValuesByStatement(
+            PreparedStatement ps, int columnIndex, Predicate<String> filterFunc, Object... params)
+            throws SQLException {
+        List<String> columnValues = Lists.newArrayList();
+        if (Objects.nonNull(params) && params.length > 0) {
+            for (int i = 0; i < params.length; i++) {
+                ps.setObject(i + 1, params[i]);
+            }
+        }
+        try (ResultSet rs = ps.executeQuery()) {
+            while (rs.next()) {
+                String columnValue = rs.getString(columnIndex);
+                if (Objects.isNull(filterFunc) || filterFunc.test(columnValue)) {
+                    columnValues.add(columnValue);
+                }
+            }
+        }
+        return columnValues;
+    }
+
     protected DataType fromJDBCType(ObjectPath tablePath, ResultSetMetaData metadata, int colIndex)
             throws SQLException {
         throw new UnsupportedOperationException();
