@@ -50,6 +50,7 @@ import java.util.Set;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
+import static org.apache.flink.connector.jdbc.table.JdbcConnectorOptions.COMPATIBLE_MODE;
 import static org.apache.flink.connector.jdbc.table.JdbcConnectorOptions.DRIVER;
 import static org.apache.flink.connector.jdbc.table.JdbcConnectorOptions.LOOKUP_CACHE_MAX_ROWS;
 import static org.apache.flink.connector.jdbc.table.JdbcConnectorOptions.LOOKUP_CACHE_MISSING_KEY;
@@ -89,7 +90,10 @@ public class JdbcDynamicTableFactory implements DynamicTableSourceFactory, Dynam
         helper.validate();
         validateConfigOptions(config, context.getClassLoader());
         validateDataTypeWithJdbcDialect(
-                context.getPhysicalRowDataType(), config.get(URL), context.getClassLoader());
+                context.getPhysicalRowDataType(),
+                config.get(URL),
+                config.get(COMPATIBLE_MODE),
+                context.getClassLoader());
         InternalJdbcConnectionOptions jdbcOptions =
                 getJdbcOptions(config, context.getClassLoader());
 
@@ -112,7 +116,10 @@ public class JdbcDynamicTableFactory implements DynamicTableSourceFactory, Dynam
         helper.validate();
         validateConfigOptions(config, context.getClassLoader());
         validateDataTypeWithJdbcDialect(
-                context.getPhysicalRowDataType(), config.get(URL), context.getClassLoader());
+                context.getPhysicalRowDataType(),
+                config.get(URL),
+                config.get(COMPATIBLE_MODE),
+                context.getClassLoader());
         return new JdbcDynamicTableSource(
                 getJdbcOptions(helper.getOptions(), context.getClassLoader()),
                 getJdbcReadOptions(helper.getOptions()),
@@ -122,8 +129,8 @@ public class JdbcDynamicTableFactory implements DynamicTableSourceFactory, Dynam
     }
 
     private static void validateDataTypeWithJdbcDialect(
-            DataType dataType, String url, ClassLoader classLoader) {
-        final JdbcDialect dialect = JdbcDialectLoader.load(url, classLoader);
+            DataType dataType, String url, String compatibleMode, ClassLoader classLoader) {
+        final JdbcDialect dialect = JdbcDialectLoader.load(url, compatibleMode, classLoader);
         dialect.validate((RowType) dataType.getLogicalType());
     }
 
@@ -135,7 +142,9 @@ public class JdbcDynamicTableFactory implements DynamicTableSourceFactory, Dynam
                         .setClassLoader(classLoader)
                         .setDBUrl(url)
                         .setTableName(readableConfig.get(TABLE_NAME))
-                        .setDialect(JdbcDialectLoader.load(url, classLoader))
+                        .setDialect(
+                                JdbcDialectLoader.load(
+                                        url, readableConfig.get(COMPATIBLE_MODE), classLoader))
                         .setParallelism(readableConfig.getOptional(SINK_PARALLELISM).orElse(null))
                         .setConnectionCheckTimeoutSeconds(
                                 (int) readableConfig.get(MAX_RETRY_TIMEOUT).getSeconds());
@@ -143,6 +152,7 @@ public class JdbcDynamicTableFactory implements DynamicTableSourceFactory, Dynam
         readableConfig.getOptional(DRIVER).ifPresent(builder::setDriverName);
         readableConfig.getOptional(USERNAME).ifPresent(builder::setUsername);
         readableConfig.getOptional(PASSWORD).ifPresent(builder::setPassword);
+        readableConfig.getOptional(COMPATIBLE_MODE).ifPresent(builder::setCompatibleMode);
         return builder.build();
     }
 
@@ -223,6 +233,7 @@ public class JdbcDynamicTableFactory implements DynamicTableSourceFactory, Dynam
     public Set<ConfigOption<?>> optionalOptions() {
         Set<ConfigOption<?>> optionalOptions = new HashSet<>();
         optionalOptions.add(DRIVER);
+        optionalOptions.add(COMPATIBLE_MODE);
         optionalOptions.add(USERNAME);
         optionalOptions.add(PASSWORD);
         optionalOptions.add(SCAN_PARTITION_COLUMN);
@@ -257,6 +268,7 @@ public class JdbcDynamicTableFactory implements DynamicTableSourceFactory, Dynam
                         USERNAME,
                         PASSWORD,
                         DRIVER,
+                        COMPATIBLE_MODE,
                         SINK_BUFFER_FLUSH_MAX_ROWS,
                         SINK_BUFFER_FLUSH_INTERVAL,
                         SINK_MAX_RETRIES,
@@ -268,7 +280,7 @@ public class JdbcDynamicTableFactory implements DynamicTableSourceFactory, Dynam
 
     private void validateConfigOptions(ReadableConfig config, ClassLoader classLoader) {
         String jdbcUrl = config.get(URL);
-        JdbcDialectLoader.load(jdbcUrl, classLoader);
+        JdbcDialectLoader.load(jdbcUrl, config.get(COMPATIBLE_MODE), classLoader);
 
         checkAllOrNone(config, new ConfigOption[] {USERNAME, PASSWORD});
 
