@@ -24,7 +24,4 @@ public interface SqlServerImages {
     DockerImageName MSSQL_AZURE_SQL_EDGE =
             DockerImageName.parse("mcr.microsoft.com/azure-sql-edge")
                     .asCompatibleSubstituteFor("mcr.microsoft.com/mssql/server");
-
-    String MSSQL_SERVER_2017 = "mcr.microsoft.com/mssql/server:2017-CU12";
-    String MSSQL_SERVER_2019 = "mcr.microsoft.com/mssql/server:2019-GA-ubuntu-16.04";
 }
